# Table of Contents

- [microsoft-applications-modeling-best-practices](<./microsoft-applications-modeling-best-practices.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Microsoft Applications Modeling Best Practices](<./Microsoft-Applications-Modeling-Best-Practices.md>)
  - [Microsoft Azure (IaaS)](<./Microsoft-Applications-Modeling-Best-Practices/Microsoft-Azure-IaaS.md>)
  - [Microsoft Dynamics](<./Microsoft-Applications-Modeling-Best-Practices/Microsoft-Dynamics.md>)
  - [Microsoft Office 365](<./Microsoft-Applications-Modeling-Best-Practices/Microsoft-Office-365.md>)
